==> escapework-manager-2.0.0-90a810.tar: src/Providers/ManagerServiceProvider.php <==
<?php namespace EscapeWork\Manager\Providers;

use EscapeWork\Manager\Facades\ManagerAuth;
use EscapeWork\Manager\Permission;
use EscapeWork\Manager\Validators\PasswordMatchValidator;
use Illuminate\Support\ServiceProvider;
use Illuminate\Foundation\AliasLoader;

class ManagerServiceProvider extends ServiceProvider
{

    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        /**
         * Indicates package root folder
         */
        $root = __DIR__ . '/../..';

        # publiishing files
        $this->publishes([
            $root . '/config/manager.php'  => config_path('manager.php'),
            $root . '/resources/assets'    => public_path('packages/manager'),
            $root . '/database/migrations' => 'database/migrations',
        ]);

        # loading views and translations from resources
        $this->loadViewsFrom($root . '/resources/views', 'manager');
        $this->loadTranslationsFrom($root . '/resources/translations', 'manager');
        $this->loadValidators();
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->registerMiddlewares();

        $this->registerPermission();
        $this->createAliases();

        $this->mergeConfigFrom(
            __DIR__ . '/../../config/manager.php', 'manager'
        );

        $this->callProviders();
        $this->registerCommands();
        $this->createConfigurations();
    }

    protected function registerMiddlewares()
    {
        $kernel = new \EscapeWork\Manager\Http\Kernel;

        foreach ($kernel->getMiddlewares() as $key => $middleware) {
            $this->app->router->middleware($key, $middleware);
        }
    }

    /**
     * Registering the permission check class
     */
    protected function registerPermission()
    {
        $this->app['escapework.manager.permission'] = $this->app->share(function($app)
        {
            $user = ManagerAuth::user();

            $permission = $app->make('EscapeWork\Manager\Permission', [$user]);
            $permission->fetchAllowedActions();

            return $permission;
        });
    }

    /**
     * Calling the providers needed
     */
    protected function callProviders()
    {
        $this->app->register('EscapeWork\Manager\Providers\RouteServiceProvider');
        $this->app->register('EscapeWork\Manager\Providers\UserServiceProvider');
        $this->app->register('EscapeWork\Manager\Providers\PasswordServiceProvider');
        $this->app->register('EscapeWork\Manager\Providers\ResponseServiceProvider');
        $this->app->register('Illuminate\Html\HtmlServiceProvider');

        if ($this->app['request']->is(config('manager.url') . '/*')) {
            # handling manager errors
            $this->app->singleton(
                'Illuminate\Contracts\Debug\ExceptionHandler',
                'EscapeWork\Manager\Exceptions\Handler'
            );

            # off por enquanto
            # $this->app->register('EscapeWork\Manager\Providers\EventServiceProvider');
        }
    }

    protected function createAliases()
    {
        $this->app->booting(function()
        {
            $loader = AliasLoader::getInstance();

            $loader->alias('Check', 'EscapeWork\Manager\Facades\Check');
            $loader->alias('Form', 'Illuminate\Html\FormFacade');
        });
    }

    /**
     * Registrando os comandos
     */
    public function registerCommands()
    {
        $this->commands(
            'EscapeWork\Manager\Console\ConfigureCommand',
            'EscapeWork\Manager\Console\CreateUserCommand',
            'EscapeWork\Manager\Console\UpdatePasswordCommand',

            'EscapeWork\Manager\Console\CrudGeneratorCommand',
            'EscapeWork\Manager\Console\ControllerMakeCommand',
            'EscapeWork\Manager\Console\RequestMakeCommand',
            'EscapeWork\Manager\Console\ModelMakeCommand',
            'EscapeWork\Manager\Console\RepositoryMakeCommand',
            'EscapeWork\Manager\Console\CommandMakeCommand',
            'EscapeWork\Manager\Console\ViewsMakeCommand'
        );
    }

    /**
     * Criando as configurações em tempo de execução
     */
    protected function createConfigurations()
    {
        $this->app['config']->set('manager.packages', []);

        $this->app['config']['manager.permissions.pages'] = array_merge(
            $this->app['config']['manager.permissions.pages'],
            [
                'users' => [
                    'title'   => 'Usuários',
                    'actions' => [], // ex: create, read, update, delete, etc
                ],

                'roles' => [
                    'title'   => 'Perfis',
                    'actions' => [], // ex: create, read, update, delete, etc
                ],
            ]
        );
    }

        /**
     * Resolving validators
     * @return void
     */
    protected function loadValidators()
    {
        $this->app->validator->extend('password_match', 'EscapeWork\Manager\Validators\PasswordMatchValidator@validate');
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return [
            'escapework.manager.permission',
        ];
    }
}

==> escapework-manager-4.2.4-3b065a.tar: src/Providers/ManagerServiceProvider.php <==
<?php

namespace EscapeWork\Manager\Providers;

use EscapeWork\Manager\Permission;
use EscapeWork\Manager\Validators\PasswordMatchValidator;
use Illuminate\Support\ServiceProvider;
use Illuminate\Foundation\AliasLoader;
use Auth;

class ManagerServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        /**
         * Indicates package root folder
         */
        $root = __DIR__ . '/../..';

        # publiishing files
        $this->publishes([
            $root . '/public/components' => public_path('packages/manager/components'),
            $root . '/public/css'        => public_path('packages/manager/css'),
            $root . '/public/fonts'      => public_path('packages/manager/fonts'),
            $root . '/public/img'        => public_path('packages/manager/img'),
            $root . '/public/js'         => public_path('packages/manager/js'),
            $root . '/public/themes'      => public_path('packages/manager/themes')
        ], 'public');

        $this->publishes([
            $root . '/config/manager.php'  => config_path('manager.php'),
            $root . '/database/migrations' => 'database/migrations',
        ], 'config');

        # loading views and translations from resources
        $this->loadViewsFrom($root . '/resources/views', 'manager');
        $this->loadTranslationsFrom($root . '/resources/translations', 'manager');
        $this->loadValidators();

        $this->createConfigurations();
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->registerMiddlewares();
        $this->registerPermission();

        $this->mergeConfigFrom(
            __DIR__ . '/../../config/manager.php', 'manager'
        );

        $this->callProviders();
        $this->registerCommands();
    }

    /**
     * Registering the permission check class
     */
    protected function registerPermission()
    {
        $this->app->singleton('escapework.manager.permission', function($app)
        {
            return new Permission(Auth::guard('manager')->user());
        });
    }

    protected function registerMiddlewares()
    {
        $this->app['router']->aliasMiddleware('manager.authenticated', \EscapeWork\Manager\Http\Middleware\IsAuthenticated::class);
        $this->app['router']->aliasMiddleware('manager.guest', \EscapeWork\Manager\Http\Middleware\UnauthorizeIfGuest::class);
        $this->app['router']->aliasMiddleware('manager.hasPermission', \EscapeWork\Manager\Http\Middleware\HasPermission::class);
        $this->app['router']->aliasMiddleware('manager.mediable', \EscapeWork\Manager\Http\Middleware\Mediable::class);
    }

    /**
     * Calling the providers needed
     */
    protected function callProviders()
    {
        $this->app->register('EscapeWork\Manager\Providers\RouteServiceProvider');
        $this->app->register('EscapeWork\Manager\Providers\UserServiceProvider');

        if ($this->app['request']->is(config('manager.url') . '/*')) {
            $this->app->register('EscapeWork\Manager\Providers\ResponseServiceProvider');
            $this->app->register('Rap2hpoutre\LaravelLogViewer\LaravelLogViewerServiceProvider');

            # handling manager errors
            $this->app->singleton(
                'Illuminate\Contracts\Debug\ExceptionHandler',
                'EscapeWork\Manager\Exceptions\Handler'
            );
        }
    }

    /**
     * Registrando os comandos
     */
    public function registerCommands()
    {
        if (! $this->app->runningInConsole()) {
            return;
        }

        $this->commands(
            'EscapeWork\Manager\Console\ConfigureCommand',
            'EscapeWork\Manager\Console\CreateUserCommand',
            'EscapeWork\Manager\Console\UpdatePasswordCommand',

            'EscapeWork\Manager\Console\CrudGeneratorCommand',
            'EscapeWork\Manager\Console\CrudGeneratorTemplateCommand',
            'EscapeWork\Manager\Console\ControllerMakeCommand',
            'EscapeWork\Manager\Console\RequestMakeCommand',
            'EscapeWork\Manager\Console\ModelMakeCommand',
            'EscapeWork\Manager\Console\RepositoryMakeCommand',
            'EscapeWork\Manager\Console\ViewsMakeCommand',
            'EscapeWork\Manager\Console\PresenterMakeCommand',
            'EscapeWork\Manager\Console\MigrationMakeCommand'
        );
    }

    /**
     * Criando as configurações em tempo de execução
     */
    protected function createConfigurations()
    {
        $this->app['config']->set('manager.packages', []);

        $this->app['config']['manager.permissions.pages'] = array_merge(
            $this->app['config']['manager.permissions.pages'],
            [
                'manager_users' => [
                    'title'   => 'Manager - Usuários',
                    'actions' => [], // ex: create, read, update, delete, etc
                ],

                'manager_roles' => [
                    'title'   => 'Manager - Perfis de usuários',
                    'actions' => [], // ex: create, read, update, delete, etc
                ],
            ]
        );
    }

    /**
     * Resolving validators
     * @return void
     */
    protected function loadValidators()
    {
        $this->app->validator->extend('password_match', 'EscapeWork\Manager\Validators\PasswordMatchValidator@validate');
    }
}
